---
title: '정산내역과 지급내역은 어떤 차이가 있고 어디서 확인할 수 있나요? '
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: ''
tags:
  - 정산내역관리
  - 지급내역관리
  - 기본 가이드
pgCompanies:
  - 공통
searchTags:
  - 정산상세조회
  - 정산내역관리
  - 일괄지급내역관리
  - 지급내역관리
  - 주문 정산
  - 주문 취소 정산
  - 수기 정산 API
  - 주문 정산 API
  - 지급내역
  - 정산내역
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="정산내역은 어떤 파트너에게 얼마의 정산금이 지급되어야 하는지 계산된 최소 단위이고
지급내역은 파트너에게 실제로 이체를하여 지급을 할 수 있는 최소 단위입니다. " title="" />

### 정산 내역이란?

- 정산내역은 어떤 파트너에게 얼마의 정산금이 지급되어야 하는지 계산된 최소 단위입니다.
- 정산 유형은 아래와 같습니다.
  - 주문 정산, 주문 취소 정산, 수기 정산
- 정산내역 관련 API 를 개발한 경우, 총 3가지 유형의 정산 내역을 만들 수 있습니다.
  - 주문 정산 생성 API를 호출 시 주문 내역을 기준으로 정산금액을 자동으로 계산하여 정산 내역을 만듭니다.
  - 또한 주문 취소 정산 API를 호출 시 주문 내역을 기준으로 정산 취소 금액을 자동으로 계산하여 정산 취소 내역을 만듭니다.
  - 수기 정산 API를 호출 시, 어떤 파트너에게 언제 얼마를 정산해야 하는지 입력한 금액을 기준으로 정산 내역을 만듭니다.
- 수기로 정산 건을 등록하는 경우, 수기 정산 내역을 만들 수 있습니다.
  - 어떤 파트너에게 언제 얼마를 정산해야 하는지 입력한 금액을 기준으로 정산 내역을 만듭니다.
  - 단 건의 수기 정산 건을 만들 수도 있고, CSV 파일을 업로드하여 대량으로 수기 정산 건을 만들 수 있습니다.

### 지급 내역이란?

- 지급내역은 파트너에게 실제로 이체를 하여 지급을 할 수 있는 최소 단위입니다.
- 송금대행 일괄지급 기능을 이용할 경우, 파트너 아이디를 기준으로 지급 내역이 자동으로 생성됩니다.

### 정산 내역은 어디서 확인할 수 있고 어떤 기능이 있나요?

##### 정산 상세 조회

- 정산 내역은 \[정산내역조회] 페이지에서 확인할 수 있습니다.
- \[엑셀 다운로드] 기능을 이용할 수 있습니다. ![](</uploads/파트너정산자동화/정산상세조회 스크린샷.png>)

##### 정산 내역 관리

- 정산 내역은 \[정산내역조회] 페이지에서도 확인할 수 있지만, 실제 정산일이 도래하면 \[정산내역관리] 페이지에서 내역을 확인할 수 있습니다.
- 정산 내역 관리 페이지에서는 원하는 정산 건을 선택하여 \[송금대행 일괄지급]을 할 수 있습니다.
- \[엑셀 다운로드] 기능을 이용할 수 있습니다. ![](/uploads/파트너정산자동화/정산내역관리.png)

### 지급 내역은 어디서 확인할 수 있고 어떤 기능이 있나요?

##### 일괄 지급 내역 관리

- \[송금대행 일괄지급]을 실행한 경우, 파트너들에게 대량으로 지급한 내역에 대해서 이력을 관리할 수 있습니다.
- 1건의 일괄지급 건에 대한 지급 내역들의 요약된 정보를 확인할 수 있습니다. 각 일괄지급 건별로 지급예정/지급성공/지급실패가 몇 건인지 상태를 확인하고 관리할 수 있습니다.

![](/uploads/파트너정산자동화/일괄지급내역관리.png)

##### 지급 내역 관리

- \[송금대행 일괄지급]을 실행한 경우, 파트너들에게 지급한 건별 내역에 대해서 이력을 관리할 수 있습니다.
- 각 지급 건별로 지급 상태를 확인하고, 지급 실패 시 세부적인 사유에 대해서도 확인할 수 있습니다.

![](/uploads/파트너정산자동화/지급내역관리.png)

### 추가 질문이 있으시다면?

아래 연락처로 언제든지 편히 문의해주세요.

<Callout content="기술 문의 지원 이메일
b2b.support@portone.io" />

###
